<?php

namespace Drupal\commerce_globalonepay\PluginForm;

use Drupal\commerce_price\Price;
use Drupal\Core\Form\FormStateInterface;
use Drupal\commerce_payment\PluginForm\PaymentRefundForm;

/**
 * Extend existing Refund form with Reason field.
 */
class RefundForm extends PaymentRefundForm {

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    // Build main refund form.
    $form = parent::buildConfigurationForm($form, $form_state);
    // Add additional field required by GlobalOnePay system.
    $form['reason'] = [
      '#type' => 'textfield',
      '#title' => t('Reason'),
      '#description' => t('The reason for the refund.'),
      '#default_value' => t('Wrong payment.'),
      '#required' => TRUE,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValue($form['#parents']);
    $amount = new Price($values['amount']['number'], $values['amount']['currency_code']);
    $reason = $values['reason'];
    /** @var \Drupal\commerce_payment\Entity\PaymentInterface $payment */
    $payment = $this->entity;
    /** @var \Drupal\commerce_payment\Plugin\Commerce\PaymentGateway\SupportsRefundsInterface $payment_gateway_plugin */
    $payment_gateway_plugin = $this->plugin;
    $payment_gateway_plugin->refundPayment($payment, $amount, $reason);
  }

}
